@@ -1,6 +1,6 @@
 /**************************************************************************
  *  PipeWalker game (http://pipewalker.sourceforge.net)                   *
- *  Copyright (C) 2007-2009 by Artem A. Senichev <artemsen@gmail.com>     *
+ *  Copyright (C) 2007-2010 by Artem A. Senichev <artemsen@gmail.com>     *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -19,6 +19,14 @@
 #pragma once
 
 #include "common.h"
+#include "texture.h"
+
+class CGame;
+
+#ifdef _MSC_VER
+#pragma warning(disable: 4512)	//assignment operator could not be generated
+#endif // _MSC_VER
+
 
 /**
  * CButton - Simple button
@@ -26,11 +34,26 @@
 class CButton
 {
 public:
-	//! Default constructor
-	CButton();
+	/**
+	 * Constructor
+	 * \param game the game instance
+	 */
+	CButton(CGame& game);
 
 	/**
 	 * Constructor
+	 * \param game the game instance
+	 * \param x button x coordinate
+	 * \param y button y coordinate
+	 * \param width button width
+	 * \param height button height
+	 * \param tex button texture identifier
+	 * \param id button texture ID
+	 */
+	CButton(CGame& game, const float x, const float y, const float width, const float height, const CTextureBank::TextureType tex, const int id);
+
+	/**
+	 * Button initialization
 	 * \param x button x coordinate
 	 * \param y button y coordinate
 	 * \param width button width
@@ -38,7 +61,7 @@ public:
 	 * \param tex button texture identifier
 	 * \param id button ID
 	 */
-	CButton(const float x, const float y, const float width, const float height, const GLuint tex, const int id);
+	void Init(const float x, const float y, const float width, const float height, const CTextureBank::TextureType tex, const int id);
 
 	/**
 	 * Check for cross mouse and button coordinates
@@ -52,7 +75,7 @@ public:
 	 * Get button ID
 	 * \return button ID
 	 */
-	int GetId() const	{ return m_BtnId; }
+	int GetId() const	{ return _BtnId; }
 
 	/**
 	 * Render button
@@ -69,16 +92,17 @@ protected:
 	 * \param y mouse y coordinate
 	 * \param texture texture identifier
 	 */
-	void RenderButton(const float x, const float y, const GLuint texture) const;
+	void RenderButton(const float x, const float y, const CTextureBank::TextureType texture) const;
 
 
 protected:	//Class variables
-	float	m_X;		///< Button x coordinate
-	float	m_Y;		///< Button y coordinate
-	float	m_Width;	///< Button width
-	float	m_Height;	///< Button height
-	GLuint	m_TexId;	///< Button texture identifier
-	int		m_BtnId;	///< Button ID
+	CGame&	_Game;		///< Game instance
+	float	_X;		///< Button x coordinate
+	float	_Y;		///< Button y coordinate
+	float	_Width;	///< Button width
+	float	_Height;	///< Button height
+	int		_BtnId;	///< Button ID
+	CTextureBank::TextureType	_TexId;	///< Button texture identifier
 };
 
 
@@ -88,11 +112,15 @@ protected:	//Class variables
 class CCheckBoxButton : public CButton
 {
 public:
-	//! Default constructor
-	CCheckBoxButton() : CButton(), m_State(false), m_TexOff(0) {}
+	/**
+	 * Constructor
+	 * \param game the game instance
+	 */
+	CCheckBoxButton(CGame& game) : CButton(game), _State(false), _TexOff(CTextureBank::TexCounter) {}
 
 	/**
 	 * Constructor
+	 * \param game the game instance
 	 * \param state initial button state (on/off)
 	 * \param x button x coordinate
 	 * \param y button y coordinate
@@ -102,26 +130,26 @@ public:
 	 * \param texOff button off-state texture identifier
 	 * \param id button ID
 	 */
-	CCheckBoxButton(const bool state, const float x, const float y, const float width, const float height, const GLuint texOn, const GLuint texOff, const int id);
+	CCheckBoxButton(CGame& game, const bool state, const float x, const float y, const float width, const float height, const CTextureBank::TextureType texOn, const CTextureBank::TextureType texOff, const int id);
 
 	/**
 	 * Get button state
 	 * \return button state
 	 */
-	bool GetState()	const				{ return m_State; }
+	bool GetState()	const				{ return _State; }
 
 	/**
 	 * Set button state
 	 * \param newState new state
 	 */
-	void SetState(const bool newState)	{ m_State = newState; }
+	void SetState(const bool newState)	{ _State = newState; }
 
 	// From CButton
 	virtual void Render(const float x, const float y) const;
 
 protected:
-	bool	m_State;	///< Button state (on/off)
-	GLuint	m_TexOff;	///< Button second texture identifier
+	bool	_State;	///< Button state (on/off)
+	CTextureBank::TextureType	_TexOff;	///< Button second texture identifier
 };
 
 
@@ -165,5 +193,5 @@ public:
 	void SetChoice(const int choiceId);
 
 private:
-	vector<CCheckBoxButton>	m_Buttons;	///< Buttons groupe
+	list<CCheckBoxButton>	_Buttons;	///< Buttons group
 };
