@@ -1,6 +1,6 @@
 /**************************************************************************
  *  PipeWalker game (http://pipewalker.sourceforge.net)                   *
- *  Copyright (C) 2007-2009 by Artem A. Senichev <artemsen@gmail.com>     *
+ *  Copyright (C) 2007-2010 by Artem A. Senichev <artemsen@gmail.com>     *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -41,9 +41,9 @@ struct IMAGE_TGA_HEADER {
 
 
 CImage::CImage()
-:	m_ImgWidth(0),
-	m_ImgHeight(0),
-	m_ImgMode(GL_RGB)
+:	_ImgWidth(0),
+	_ImgHeight(0),
+	_ImgMode(GL_RGB)
 {
 }
 
@@ -66,16 +66,16 @@ void CImage::Load(const char* fileName)
 		throw CException("TGA: Only RLE or RGB mode supported");
 
 	//Read the width and height
-	m_ImgWidth  = header->Width;
-	m_ImgHeight = header->Height;
- 	if (m_ImgWidth == 0 || m_ImgHeight == 0 || m_ImgWidth > 4096 || m_ImgHeight > 4096)
+	_ImgWidth  = header->Width;
+	_ImgHeight = header->Height;
+ 	if (_ImgWidth == 0 || _ImgHeight == 0 || _ImgWidth > 4096 || _ImgHeight > 4096)
 		throw CException("TGA: Undefined image size");
 
 	//Define format
 	if (header->PixelSize == 24)
-		m_ImgMode = GL_RGB;
+		_ImgMode = GL_RGB;
 	else if (header->PixelSize == 32)
-		m_ImgMode = GL_RGBA;
+		_ImgMode = GL_RGBA;
 	else
 		throw CException("TGA: Pixel size unsupported");
 
@@ -83,12 +83,12 @@ void CImage::Load(const char* fileName)
 	const size_t bpp = header->PixelSize / 8;
 
 	//Calculate the size
-	const size_t sizeInBytes = m_ImgWidth * m_ImgHeight * bpp;
+	const size_t sizeInBytes = _ImgWidth * _ImgHeight * bpp;
 
 	//Read the data
-	m_Data.resize(sizeInBytes);
+	_Data.resize(sizeInBytes);
 	if (header->ImageType == IMAGE_TGA_RGB)
-		memcpy(&m_Data[0], buf.GetData(sizeInBytes), sizeInBytes);
+		memcpy(&_Data[0], buf.GetData(sizeInBytes), sizeInBytes);
 	else {
 		//Create new own buffer to store image data
 		size_t bufPos = 0;
@@ -103,12 +103,12 @@ void CImage::Load(const char* fileName)
 				for (unsigned int j = 0; j < packetLength * bpp; ++j) {
 					if (bufPos >= sizeInBytes)
 						throw CException("TGA: Incorrect format");
-					m_Data[bufPos++] = packet[j % bpp];
+					_Data[bufPos++] = packet[j % bpp];
 				}
 			}
 			else {								//Raw packet
 				for (size_t j = 0; j < packetLength * bpp; ++j) {
-					if (bufPos >= sizeInBytes || !buf.Get(m_Data[bufPos++]))
+					if (bufPos >= sizeInBytes || !buf.Get(_Data[bufPos++]))
 						throw CException("TGA: Incorrect format");
 				}
 			}
@@ -127,69 +127,70 @@ void CImage::LoadXPM(const char* data[], const size_t strNum)
 {
 	assert(data);
 
-	//Read image properties
-	const char* token = data[0];
-	m_ImgMode = GL_RGBA;
-	m_ImgWidth = atoi(data[0]);
-	token = strchr(token + 1, ' ') + 1;
-	m_ImgHeight = atoi(token);
+	_ImgMode = GL_RGBA;
 
-	token = strchr(token + 1, ' ') + 1;
-	const size_t colorMapSize = atoi(token);
-	token = strchr(token + 1, ' ') + 1;
-	const size_t bytePerPixel = atoi(token);
-	assert(strNum > bytePerPixel);
+	//Read image properties
+	int colorMapSize = 0, bytePerPixel = 0, imgWidth = 0, imgHeight = 0;
+	sscanf(data[0], "%i %i %i %i", &imgWidth, &imgHeight, &colorMapSize, &bytePerPixel);
+	_ImgWidth = static_cast<size_t>(imgWidth);
+	_ImgHeight = static_cast<size_t>(imgHeight);
 
 	//Read the color map
 	map< string, vector<unsigned char> > colorMap;
-	for (size_t i = 1; i <= colorMapSize; ++i) {
-		if (i >= strNum)
+	for (int i = 1; i <= colorMapSize; ++i) {
+		if (i >= static_cast<int>(strNum))
 			throw CException("XPM: Incorrect format");
 
 		const string index(data[i], data[i] + bytePerPixel);
 		vector<unsigned char> color;
-		color.resize(4);
+		color.resize(4, 0);
 		if (strcmp(data[i] + bytePerPixel + 3, "None") != 0) {
 			unsigned int colorRef = 0;
 			sscanf(data[i] + bytePerPixel + 4, "%x", &colorRef);
+#ifdef PW_BYTEORDER_LITTLE_ENDIAN
 			color[0] = static_cast<unsigned char>((colorRef & 0x00ff0000) >> 16);
 			color[1] = static_cast<unsigned char>((colorRef & 0x0000ff00) >> 8);
 			color[2] = static_cast<unsigned char>((colorRef & 0x000000ff) >> 0);
+#else
+			color[0] = static_cast<unsigned char>((colorRef & 0xff000000) << 0);
+			color[1] = static_cast<unsigned char>((colorRef & 0x00ff0000) << 8);
+			color[2] = static_cast<unsigned char>((colorRef & 0x0000ff00) << 16);
+#endif	//PW_BYTEORDER_LITTLE_ENDIAN
 			color[3] = 0xff;	//Non transparent
 		}
 		colorMap.insert(make_pair(index, color));
 	}
 
 	//Read image data
-	m_Data.reserve(SizeInBytes());
-	for (size_t i = 0; i < m_ImgHeight; ++i) {
+	_Data.reserve(SizeInBytes());
+	for (size_t i = 0; i < _ImgHeight; ++i) {
 		if (i + colorMapSize + 1 >= strNum)
 			throw CException("XPM: Incorrect format");
 		const char* imgData = data[i + colorMapSize + 1];
-		for (size_t j = 0; j < m_ImgWidth; ++j) {
+		for (size_t j = 0; j < _ImgWidth; ++j) {
 			const string colorIndex(imgData + j * bytePerPixel, imgData + j * bytePerPixel + bytePerPixel);
 			const vector<unsigned char> colorValue = colorMap[colorIndex];
 			assert(colorValue.size() == 4);
-			copy(colorValue.begin(), colorValue.end(), back_inserter(m_Data));
+			copy(colorValue.begin(), colorValue.end(), back_inserter(_Data));
 		}
 	}
-	assert(m_Data.size() == SizeInBytes());
+	assert(_Data.size() == SizeInBytes());
 }
 
 
 void CImage::GetSubImage(const size_t x, const size_t y, const size_t width, const size_t height, vector<unsigned char>& data) const
 {
-	assert(!m_Data.empty());
-	assert(m_ImgMode == GL_RGB || m_ImgMode == GL_RGBA);
+	assert(!_Data.empty());
+	assert(_ImgMode == GL_RGB || _ImgMode == GL_RGBA);
 
-	if (x > m_ImgWidth || x + width > m_ImgWidth || y > m_ImgHeight || y + height > m_ImgHeight)
+	if (x > _ImgWidth || x + width > _ImgWidth || y > _ImgHeight || y + height > _ImgHeight)
 		throw CException("Sub image coordinates out of range");
 
 	const unsigned char bpp = BytesPerPixel();
 
 	data.reserve(height * width * bpp);
 	for (size_t i = 0; i < height; ++i) {
-		const vector<unsigned char>::const_iterator itCopy = m_Data.begin() + x * bpp + (i + y) * m_ImgWidth * bpp;
+		const vector<unsigned char>::const_iterator itCopy = _Data.begin() + x * bpp + (i + y) * _ImgWidth * bpp;
 		copy(itCopy, itCopy + width * bpp, back_inserter(data));
 	}
 }
@@ -197,34 +198,34 @@ void CImage::GetSubImage(const size_t x, const size_t y, const size_t width, con
 
 void CImage::ConvertBGRtoRGB()
 {
-	assert(!m_Data.empty());
-	assert(m_ImgMode == GL_RGB || m_ImgMode == GL_RGBA);
+	assert(!_Data.empty());
+	assert(_ImgMode == GL_RGB || _ImgMode == GL_RGBA);
 
-	if (m_ImgMode != GL_RGB && m_ImgMode != GL_RGBA)
+	if (_ImgMode != GL_RGB && _ImgMode != GL_RGBA)
 		return;	//One-component image
 
 	const unsigned short bpp = BytesPerPixel();
 	const size_t sizeInBytes = SizeInBytes();
 
 	for (unsigned int i = 0; i < sizeInBytes; i += bpp) {
-		unsigned char tmp = m_Data[i];
-		m_Data[i] = m_Data[i + 2];
-		m_Data[i + 2] = tmp;
+		unsigned char tmp = _Data[i];
+		_Data[i] = _Data[i + 2];
+		_Data[i + 2] = tmp;
 	}
 }
 
 
 void CImage::FlipVertical()
 {
-	assert(!m_Data.empty());
+	assert(!_Data.empty());
 
-	const unsigned int sizeWidth = m_ImgWidth * BytesPerPixel();
+	const unsigned int sizeWidth = static_cast<unsigned int>(_ImgWidth * BytesPerPixel());
 	vector<unsigned char> swapBuffer;
 	swapBuffer.resize(sizeWidth);
 
-	for (unsigned int i = 0; i < m_ImgHeight / 2; ++i) {
-		unsigned char* srcData = &m_Data[i * sizeWidth];
-		unsigned char* dstData = &m_Data[(m_ImgHeight - i - 1) * sizeWidth];
+	for (unsigned int i = 0; i < _ImgHeight / 2; ++i) {
+		unsigned char* srcData = &_Data[i * sizeWidth];
+		unsigned char* dstData = &_Data[(_ImgHeight - i - 1) * sizeWidth];
 
 		memcpy(&swapBuffer[0], dstData, sizeWidth);
 		memcpy(dstData, srcData, sizeWidth);
