@@ -1,6 +1,6 @@
 /**************************************************************************
  *  PipeWalker game (http://pipewalker.sourceforge.net)                   *
- *  Copyright (C) 2007-2009 by Artem A. Senichev <artemsen@gmail.com>     *
+ *  Copyright (C) 2007-2010 by Artem A. Senichev <artemsen@gmail.com>     *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -22,10 +22,10 @@
 
 //! Map sizes
 enum MapSize {
-	MapSizeSmall = 10,
+	MapSizeSmall  = 10,
 	MapSizeNormal = 14,
-	MapSizeBig = 20,
-	MapSizeExtra = 30
+	MapSizeBig    = 20,
+	MapSizeExtra  = 30
 };
 
 
@@ -67,7 +67,7 @@ public:
 	 * Get "game over" flag
 	 * \return "game over" flag
 	 */
-	inline bool IsGameOver() const	{ return m_GameOver; }
+	inline bool IsGameOver() const	{ return _GameOver; }
 
 	/**
 	 * Get object's cell
@@ -94,7 +94,7 @@ public:
 	 * Get current map size
 	 * \return current map size
 	 */
-	MapSize GetMapSize() const	{ return static_cast<MapSize>(m_MapSize); }
+	MapSize GetMapSize() const	{ return static_cast<MapSize>(_MapSize); }
 
 
 private:
@@ -141,10 +141,10 @@ private:
 
 
 private:	//Class variables
-	vector<CCell>	m_CellMap;				///< Object's map
-	bool			m_GameOver;				///< Game over flag
-	bool			m_WrapMode;				///< Wrapping mode on/off flag
-	unsigned short	m_SenderX, m_SenderY;	///< Sender coordinates
-	unsigned short	m_ZeroX, m_ZeroY;		///< Zero point coordinates (sender out)
-	unsigned short	m_MapSize;				///< Map size
+	vector<CCell>	_CellMap;			///< Object's map
+	bool			_GameOver;			///< Game over flag
+	bool			_WrapMode;			///< Wrapping mode on/off flag
+	unsigned short	_SenderX, _SenderY;	///< Sender coordinates
+	unsigned short	_ZeroX, _ZeroY;		///< Zero point coordinates (sender out)
+	unsigned short	_MapSize;			///< Map size
 };
