@@ -1,6 +1,6 @@
 /**************************************************************************
  *  PipeWalker game (http://pipewalker.sourceforge.net)                   *
- *  Copyright (C) 2007-2009 by Artem A. Senichev <artemsen@gmail.com>     *
+ *  Copyright (C) 2007-2010 by Artem A. Senichev <artemsen@gmail.com>     *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -21,13 +21,11 @@
 	#include "buffer.h"
 #endif //PW_USE_WIN
 
-bool CSoundBank::m_SoundInitialized = false;
-CSound CSoundBank::m_Sound[SndCounter];
-
 #ifdef PW_USE_SDL
 	#define PW_AUDIO_FORMAT		AUDIO_S16
-	#define PW_AUDIO_FREQ		22050
-	#define PW_AUDIO_CHANNELS	1
+	#define PW_AUDIO_FREQ		44100
+	#define PW_AUDIO_CHANNELS	2
+	CSoundBank::SoundType CSoundBank::_CurrentSnd = CSoundBank::SndCounter;
 #endif //PW_USE_SDL
 
 //! Types and files of textures
@@ -37,9 +35,69 @@ struct SndFile {
 };
 
 static const SndFile SoundFiles[] = {
-	{ CSoundBank::SndClatz,	"clatz.wav"	},
+	{ CSoundBank::SndClatz,		"clatz.wav"		},
+	{ CSoundBank::SndComplete,	"complete.wav"	},
 };
 
+CSound::~CSound()
+{
+	Free();
+}
+
+
+void CSound::Load(const char* fileName)
+{
+	assert(fileName);
+
+#if defined PW_USE_SDL		//SDL library
+	SDL_AudioSpec wave;
+	Uint8* data;
+	Uint32 dlen;
+	if (SDL_LoadWAV(fileName, &wave, &data, &dlen) == NULL) {
+		string errDescr = "Unable to load file (SDL_LoadWAV) ";
+		errDescr += fileName;
+		errDescr += ": ";
+		errDescr += SDL_GetError();
+		throw CException(errDescr.c_str());
+	}
+	copy(data, data + dlen, back_inserter(_Data));
+	_Pos = 0;
+#elif defined PW_USE_WIN	//Microsoft Windows
+	CBuffer buf;
+	buf.Load(fileName);
+	buf.Copy(_Data);
+#endif
+}
+
+
+void CSound::Free()
+{
+#if defined PW_USE_SDL		//SDL library
+	_Pos = 0;
+#endif
+	_Data.clear();
+}
+
+
+CSound::CSound()
+#if defined PW_USE_SDL
+	: _Pos(0)
+#endif //PW_USE_SDL
+{
+}
+
+
+CSoundBank::CSoundBank()
+	: _SoundInitialized(false)
+{
+}
+
+
+CSoundBank::~CSoundBank()
+{
+	Free();
+}
+
 
 void CSoundBank::Load()
 {
@@ -54,7 +112,7 @@ void CSoundBank::Load()
 	soundAudiospec.channels = PW_AUDIO_CHANNELS;
 	soundAudiospec.samples = 512;
 	soundAudiospec.callback = OnFillBuffer;
-	soundAudiospec.userdata = NULL;
+	soundAudiospec.userdata = this;
 	if (SDL_OpenAudio(&soundAudiospec, NULL) != 0) {
 		fprintf(stderr, "Unable to open audio device: %s\n", SDL_GetError());
 		return;
@@ -70,89 +128,51 @@ void CSoundBank::Load()
 		char fileName[256];
 		strcpy(fileName, DIR_GAMEDATA);
 		strcat(fileName, SoundFiles[i].FileName);
-		m_Sound[i].Load(fileName);
+		_Sound[i].Load(fileName);
 	}
 
-	m_SoundInitialized = true;
+	_SoundInitialized = true;
 }
 
 
 void CSoundBank::Free()
 {
 	for (size_t i = 0; i < SndCounter; ++i)
-		m_Sound[i].Free();
+		_Sound[i].Free();
 }
 
 
-void CSoundBank::Play(const SoundType /*type*/)
+void CSoundBank::Play(const SoundType type)
 {
-	//assert(type >= 0 && type < SndCounter);
+	assert(type >= 0 && type < SndCounter);
 #if defined PW_USE_SDL		//SDL library
-	if (m_SoundInitialized)
+	if (_SoundInitialized) {
 		SDL_PauseAudio(0);
+		_CurrentSnd = type;
+	}
 #elif defined PW_USE_WIN	//Microsoft Windows
-	PlaySound((LPCSTR)&(m_Sound[0].m_Data[0]), NULL, SND_MEMORY | SND_ASYNC);
+	PlaySound(reinterpret_cast<LPCTSTR>(&_Sound[type]._Data.front()), NULL, SND_MEMORY | SND_ASYNC);
 #endif
 }
 
 
 #ifdef PW_USE_SDL
-void CSoundBank::OnFillBuffer(void* /*userdata*/, Uint8* stream, int len)
+void CSoundBank::OnFillBuffer(void* userdata, Uint8* stream, int len)
 {
-	const size_t i = SndClatz;
-	Uint32 amount = (m_Sound[i].m_Length - m_Sound[i].m_Pos);
+	CSoundBank* inst = reinterpret_cast<CSoundBank*>(userdata);
+
+	if (_CurrentSnd < 0 || _CurrentSnd >= SndCounter)
+		return;
+	
+	Uint32 amount = (inst->_Sound[_CurrentSnd]._Data.size() - inst->_Sound[_CurrentSnd]._Pos);
 	if (amount > static_cast<Uint32>(len))
 		amount = len;
-	SDL_MixAudio(stream, &m_Sound[i].m_Data[m_Sound[i].m_Pos], amount, SDL_MIX_MAXVOLUME);
-	m_Sound[i].m_Pos += amount;
-	if (m_Sound[i].m_Pos >= m_Sound[i].m_Length) {
-		m_Sound[i].m_Pos = 0;
+	SDL_MixAudio(stream, &inst->_Sound[_CurrentSnd]._Data[inst->_Sound[_CurrentSnd]._Pos], amount, SDL_MIX_MAXVOLUME);
+	inst->_Sound[_CurrentSnd]._Pos += amount;
+	if (inst->_Sound[_CurrentSnd]._Pos >= inst->_Sound[_CurrentSnd]._Data.size()) {
+		inst->_Sound[_CurrentSnd]._Pos = 0;
+		_CurrentSnd = SndCounter;
 		SDL_PauseAudio(1);
 	}
 }
 #endif //PW_USE_SDL
-
-
-
-void CSound::Load(const char* fileName)
-{
-	assert(fileName);
-
-#if defined PW_USE_SDL		//SDL library
-	SDL_AudioSpec wave;
-	Uint8* data;
-	Uint32 dlen;
-	if (SDL_LoadWAV(fileName, &wave, &data, &dlen) == NULL)
-		throw CException("Unable to load file ", fileName, ": ", SDL_GetError());
-
-	SDL_AudioCVT cvt;
-	SDL_BuildAudioCVT(&cvt, wave.format, wave.channels, wave.freq, PW_AUDIO_FORMAT, PW_AUDIO_CHANNELS, PW_AUDIO_FREQ);
-	cvt.buf = static_cast<Uint8*>(malloc(dlen * cvt.len_mult));
-	memcpy(cvt.buf, data, dlen);
-	cvt.len = dlen;
-	SDL_ConvertAudio(&cvt);
-	SDL_FreeWAV(data);
-
-	m_Data = cvt.buf;
-	m_Pos = 0;
-	m_Length = cvt.len_cvt;
-#elif defined PW_USE_WIN	//Microsoft Windows
-	CBuffer buf;
-	buf.Load(fileName);
-	buf.Copy(m_Data);
-#endif
-}
-
-
-void CSound::Free()
-{
-#if defined PW_USE_SDL		//SDL library
-	if (m_Data)
-		free(m_Data);
-	m_Data = NULL;
-	m_Pos = 0;
-	m_Length = 0;
-#elif defined PW_USE_WIN	//Microsoft Windows
-	m_Data.clear();
-#endif
-}
