@@ -1,6 +1,6 @@
 /**************************************************************************
  *  PipeWalker game (http://pipewalker.sourceforge.net)                   *
- *  Copyright (C) 2007-2009 by Artem A. Senichev <artemsen@gmail.com>     *
+ *  Copyright (C) 2007-2010 by Artem A. Senichev <artemsen@gmail.com>     *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -22,8 +22,6 @@
 
 #if defined PW_USE_SDL		//SDL library
 	#include <SDL/SDL.h>
-#elif defined PW_USE_WIN	//Microsoft Windows
-	#include "PipeWalkerRes.h"
 #endif
 
 /**
@@ -33,10 +31,8 @@ class CSound
 {
 public:
 	//Constructor/destructor
-#if defined PW_USE_SDL
-	CSound() : m_Data(NULL), m_Pos(0), m_Length(0) 	{}
-#endif //PW_USE_SDL
-	~CSound()										{ Free(); }
+	CSound();
+	~CSound();
 
 	/**
 	 * Free sound
@@ -51,12 +47,9 @@ public:
 
 public:
 #if defined PW_USE_SDL		//SDL library
-	Uint8*	m_Data;
-	Uint32	m_Pos;
-	Uint32	m_Length;
-#elif defined PW_USE_WIN	//Microsoft Windows
-	vector<unsigned char> m_Data;
+	size_t	_Pos;
 #endif
+	vector<unsigned char> _Data;
 };
 
 
@@ -66,35 +59,41 @@ public:
 class CSoundBank
 {
 public:
+	//Constructor/Destructor
+	CSoundBank();
+	~CSoundBank();
+
 	//! Sound types
 	enum SoundType {
 		SndClatz = 0,			///< Simple 'Clatz' sound
+		SndComplete,			///< Level complete sound
 		SndCounter				///< sound counter
 	};
 
 	/**
 	 * Initialize sound bank (load sounds from files)
 	 */
-	static void Load();
-
-	/**
-	 * Free sound bank
-	 */
-	static void Free();
+	void Load();
 
 	/**
 	 * Play sound
 	 * \param type sound identifier
 	 */
-	static void Play(const SoundType type);
+	void Play(const SoundType type);
 
 private:
+	/**
+	 * Free sound bank
+	 */
+	void Free();
+
 #ifdef PW_USE_SDL
 	//! SDL fill audio buffer callback (see SDL SDK for more info)
 	static void OnFillBuffer(void* userdata, Uint8* stream, int len);
+	static SoundType _CurrentSnd;	///< Current played sound
 #endif // PW_USE_SDL
 
 private:
-	static CSound	m_Sound[SndCounter];	///< Sound bank
-	static bool		m_SoundInitialized;		///< Sound subsystem initialization flag
+	CSound	_Sound[SndCounter];	///< Sound bank
+	bool	_SoundInitialized;	///< Sound subsystem initialization flag
 };
